.. _UserCreatedPlots:

==================
User created plots
==================

This page demonstrates usage of the :term:`user` renderer
in order to include custom generated plots or images into
a cgatreport document.


Plotting with matplotlib
========================

.. report:: UserTrackers.MatplotlibData
   :render: user

   Plot using matplotlib


Plotting with R
===============

.. report:: UserTrackers.RPlotData
   :render: user

   Plot using R


Adding pre-built images
=======================

Pre-built images can be added, including flanking text.

.. report:: UserTrackers.Images
   :render: user

   Plot pre-built images

They can also appear in a table:

.. report:: UserTrackers.Images2
   :render: user

   Plot pre-built images


